# B2L11_HUMAN_Dutta_2010_binding-Mcl-1.csv

ProteinGym Substitution Dataset for tests in biotrainer.

Downloaded from: https://marks.hms.harvard.edu/proteingym/ProteinGym_v1.3/DMS_ProteinGym_substitutions.zip
